AB-BLAST Tabular Output

## AB-BLAST 3.0 Tabular Output

### Tabular Output Description

Tab-delimited output is available from AB-BLAST 3.0 when `mformat=2` or `mformat=3` are specified on the command line. The latter option causes comment lines beginning with a pound sign (#) to be reported in the output, as well. If a query sequence identifier begins with a pound sign (#) or a backslash (\), it is escaped with a backslash; subject sequence identifiers are always reported “as is”.

The standard tokens reported in tabular output are shown in the Table 1 below. Table 2 describes tokens that appear only if certain other command line options are specified.

This file is available in PDF format here.

### Table 1. Constitutively Expressed Entities in Tabular Output

# | Label | Description
1 | `qid` | query sequence identifier
2 | `sid` | subject (database) sequence identifier
3 | `E` | the expectation or E-value
4 | `N` | the number of scores considered jointly in computing E
5 | `Sprime` | the normalized alignment score, expressed in units of bits
6 | `S` | the raw alignment score
7 | `alignlen` | the overall length of the alignment including any gaps
8 | `nident` | the number of identical letter pairs
9 | `npos` | the number of letter pairs contributing a positive score
10 | `nmism` | the number of mismatched letter pairs
11 | `pcident` | percent identity over the alignment length (as a fraction of `alignlen`)
12 | `pcpos` | percent positive letter pairs over the alignment length (as a fraction of `alignlen`)
13 | `qgaps` | number of gaps in the query sequence
14 | `qgaplen` | total length of all gaps in the query sequence
15 | `sgaps` | number of gaps in the subject sequence
16 | `sgaplen` | total length of all gaps in the subject sequence
17 | `qframe` | the reading frame in the query sequence (`+0` for protein sequences in `BLASTP` and `TBLASTN` searches)
18 | `qstart` | the starting coordinate of the alignment in the query sequence
19 | `qend` | the ending coordinate of the alignment in the query sequence
20 | `sframe` | the reading frame in the subject sequence (`+0` for protein sequences in `BLASTP` and `BLASTX` searches)
21 | `sstart` | the starting coordinate of the alignment in the subject sequence
22 | `send` | the ending coordinate of the alignment in the subject sequence

### Table 2. Conditionally Expressed Entities in Tabular Output

Label | Description | Inducing Parameter(s)
`group` | the “topcombo” group number for a set of HSPs | `topcomboN`, `topcomboE`
`links` | a dash-delimited list of consistent HSP numbers whose scores were used jointly to compute the E-value; the number of the current HSP (the HSP described by the current line of output) is enclosed in parentheses | `links`

Last modified: 2009-01-24

Return to the AB-BLAST Archives home page